public struct NVMRegion {
    private static var countryAliases: [String : Country] = [
        "Chagos Archipelago" : .BritishIndianOceanTerritory,
        "Cabo Verde" : .CapeVerde,
        "Vatican City" : .HolySee,
        "Lao People's Democratic Republic" : .Laos,
        "So. Georgia & So. Sandwich Isl." : .SouthGeorgiaAndTheSouthSandwichIslands
    ]
    
    /**
     Use this method to implement your own **Country Aliases**. Aliases are used to create a `Country`from a string.
     By default, the `Country` tries to find the most suitable country for the given string.
     But wih this method you can extend that even more.
     
     - parameter aliases: A dictionary of a string and a `Country`.
     
     - note: You can't overwrite the pre-created **Country Aliases**.
     */
    public static func implementCountryAliases(_ aliases: [String : Country]) {
        self.countryAliases = self.countryAliases.merging(aliases) { (current, _) in current }
    }
    
    internal static func getCountryAliases() -> [String : Country] {
        return self.countryAliases
    }
    
    /**
     Will give you the `Alpha2Code` for the specified country.
     
     - parameter country: A `Country` created by the `NVMRegion` Package.
     
     - returns: An `Alpha2Code` matching the given country
     */
    public static func alpha2Code(country: Country) -> Alpha2Code {
        switch country {
        case .Afghanistan:
            return .AF
        case .AlandIslands:
            return .AX
        case .Albania:
            return .AL
        case .Algeria:
            return .DZ
        case .AmericanSamoa:
            return .AS
        case .Andorra:
            return .AD
        case .Angola:
            return .AO
        case .Anguilla:
            return .AI
        case .Antarctica:
            return .AQ
        case .AntiguaAndBarbuda:
            return .AG
        case .Argentina:
            return .AR
        case .Armenia:
            return .AM
        case .Aruba:
            return .AW
        case .Australia:
            return .AU
        case .Austria:
            return .AT
        case .Azerbaijan:
            return .AZ
        case .Bahamas:
            return .BS
        case .Bahrain:
            return .BH
        case .Bangladesh:
            return .BD
        case .Barbados:
            return .BB
        case .Belarus:
            return .BY
        case .Belgium:
            return .BE
        case .Belize:
            return .BZ
        case .Benin:
            return .BJ
        case .Bermuda:
            return .BM
        case .Bhutan:
            return .BT
        case .Bolivia:
            return .BO
        case .BonaireSintEustatiusAndSaba:
            return .BQ
        case .BosniaAndHerzegovina:
            return .BA
        case .Botswana:
            return .BW
        case .BouvetIsland:
            return .BV
        case .Brazil:
            return .BR
        case .BritishIndianOceanTerritory:
            return .IO
        case .BruneiDarussalam:
            return .BN
        case .Bulgaria:
            return .BG
        case .BurkinaFaso:
            return .BF
        case .Burundi:
            return .BI
        case .CapeVerde:
            return .CV
        case .Cambodia:
            return .KH
        case .Cameroon:
            return .CM
        case .Canada:
            return .CA
        case .CaymanIslands:
            return .KY
        case .CentralAfricanRepublic:
            return .CF
        case .Chad:
            return .TD
        case .Chile:
            return .CL
        case .China:
            return .CN
        case .ChristmasIsland:
            return .CX
        case .CocosIslands:
            return .CC
        case .Colombia:
            return .CO
        case .Comoros:
            return .KM
        case .TheDemocraticRepublicOfTheCongo:
            return .CD
        case .Congo:
            return .CG
        case .CookIslands:
            return .CK
        case .CostaRica:
            return .CR
        case .Croatia:
            return .HR
        case .Cuba:
            return .CU
        case .Curacao:
            return .CW
        case .Cyprus:
            return .CY
        case .Czechia:
            return .CZ
        case .CoteDIvoire:
            return .CI
        case .Denmark:
            return .DK
        case .Djibouti:
            return .DJ
        case .Dominica:
            return .DM
        case .DominicanRepublic:
            return .DO
        case .Ecuador:
            return .EC
        case .Egypt:
            return .EG
        case .ElSalvador:
            return .SV
        case .EquatorialGuinea:
            return .GQ
        case .Eritrea:
            return .ER
        case .Estonia:
            return .EE
        case .Eswatini:
            return .SZ
        case .Ethiopia:
            return .ET
        case .FalklandIslands:
            return .FK
        case .FaroeIslands:
            return .FO
        case .Fiji:
            return .FJ
        case .Finland:
            return .FI
        case .France:
            return .FR
        case .FrenchGuiana:
            return .GF
        case .FrenchPolynesia:
            return .PF
        case .FrenchSouthernTerritories:
            return .TF
        case .Gabon:
            return .GA
        case .Gambia:
            return .GM
        case .Georgia:
            return .GE
        case .Germany:
            return .DE
        case .Ghana:
            return .GH
        case .Gibraltar:
            return .GI
        case .Greece:
            return .GR
        case .Greenland:
            return .GL
        case .Grenada:
            return .GD
        case .Guadeloupe:
            return .GP
        case .Guam:
            return .GU
        case .Guatemala:
            return .GT
        case .Guernsey:
            return .GG
        case .Guinea:
            return .GN
        case .GuineaBissau:
            return .GW
        case .Guyana:
            return .GY
        case .Haiti:
            return .HT
        case .HeardIslandAndMcDonaldIslands:
            return .HM
        case .HolySee:
            return .VA
        case .Honduras:
            return .HN
        case .HongKong:
            return .HK
        case .Hungary:
            return .HU
        case .Iceland:
            return .IS
        case .India:
            return .IN
        case .Indonesia:
            return .ID
        case .Iran:
            return .IR
        case .Iraq:
            return .IQ
        case .Ireland:
            return .IE
        case .IsleOfMan:
            return .IM
        case .Israel:
            return .IL
        case .Italy:
            return .IT
        case .Jamaica:
            return .JM
        case .Japan:
            return .JP
        case .Jersey:
            return .JE
        case .Jordan:
            return .JO
        case .Kazakhstan:
            return .KZ
        case .Kenya:
            return .KE
        case .Kiribati:
            return .KI
        case .TheDemocraticPeoplesRepublicOfKorea:
            return .KP
        case .Korea:
            return .KR
        case .Kuwait:
            return .KW
        case .Kyrgyzstan:
            return .KG
        case .Laos:
            return .LA
        case .Latvia:
            return .LV
        case .Lebanon:
            return .LB
        case .Lesotho:
            return .LS
        case .Liberia:
            return .LR
        case .Libya:
            return .LY
        case .Liechtenstein:
            return .LI
        case .Lithuania:
            return .LT
        case .Luxembourg:
            return .LU
        case .Macao:
            return .MO
        case .Madagascar:
            return .MG
        case .Malawi:
            return .MW
        case .Malaysia:
            return .MY
        case .Maldives:
            return .MV
        case .Mali:
            return .ML
        case .Malta:
            return .MT
        case .MarshallIslands:
            return .MH
        case .Martinique:
            return .MQ
        case .Mauritania:
            return .MR
        case .Mauritius:
            return .MU
        case .Mayotte:
            return .YT
        case .Mexico:
            return .MX
        case .Micronesia:
            return .FM
        case .Moldova:
            return .MD
        case .Monaco:
            return .MC
        case .Mongolia:
            return .MN
        case .Montenegro:
            return .ME
        case .Montserrat:
            return .MS
        case .Morocco:
            return .MA
        case .Mozambique:
            return .MZ
        case .Myanmar:
            return .MM
        case .Namibia:
            return .NA
        case .Nauru:
            return .NR
        case .Nepal:
            return .NP
        case .Netherlands:
            return .NL
        case .NewCaledonia:
            return .NC
        case .NewZealand:
            return .NZ
        case .Nicaragua:
            return .NI
        case .Niger:
            return .NE
        case .Nigeria:
            return .NG
        case .Niue:
            return .NU
        case .NorfolkIsland:
            return .NF
        case .NorthernMarianaIslands:
            return .MP
        case .Norway:
            return .NO
        case .Oman:
            return .OM
        case .Pakistan:
            return .PK
        case .Palau:
            return .PW
        case .Palestine:
            return .PS
        case .Panama:
            return .PA
        case .PapuaNewGuinea:
            return .PG
        case .Paraguay:
            return .PY
        case .Peru:
            return .PE
        case .Philippines:
            return .PH
        case .Pitcairn:
            return .PN
        case .Poland:
            return .PL
        case .Portugal:
            return .PT
        case .PuertoRico:
            return .PR
        case .Qatar:
            return .QA
        case .RepublicOfNorthMacedonia:
            return .MK
        case .Romania:
            return .RO
        case .RussianFederation:
            return .RU
        case .Rwanda:
            return .RW
        case .Reunion:
            return .RE
        case .SaintBarthelemy:
            return .BL
        case .SaintHelenaAscensionAndTristanDaCunha:
            return .SH
        case .SaintKittsAndNevis:
            return .KN
        case .SaintLucia:
            return .LC
        case .SaintMartin:
            return .MF
        case .SaintPierreAndMiquelon:
            return .PM
        case .SaintVincentAndTheGrenadines:
            return .VC
        case .Samoa:
            return .WS
        case .SanMarino:
            return .SM
        case .SaoTomeAndPrincipe:
            return .ST
        case .SaudiArabia:
            return .SA
        case .Senegal:
            return .SN
        case .Serbia:
            return .RS
        case .Seychelles:
            return .SC
        case .SierraLeone:
            return .SL
        case .Singapore:
            return .SG
        case .SintMaarten:
            return .SX
        case .Slovakia:
            return .SK
        case .Slovenia:
            return .SI
        case .SolomonIslands:
            return .SB
        case .Somalia:
            return .SO
        case .SouthAfrica:
            return .ZA
        case .SouthGeorgiaAndTheSouthSandwichIslands:
            return .GS
        case .SouthSudan:
            return .SS
        case .Spain:
            return .ES
        case .SriLanka:
            return .LK
        case .Sudan:
            return .SD
        case .Suriname:
            return .SR
        case .SvalbardAndJanMayen:
            return .SJ
        case .Sweden:
            return .SE
        case .Switzerland:
            return .CH
        case .SyrianArabRepublic:
            return .SY
        case .Taiwan:
            return .TW
        case .Tajikistan:
            return .TJ
        case .Tanzania:
            return .TZ
        case .Thailand:
            return .TH
        case .TimorLeste:
            return .TL
        case .Togo:
            return .TG
        case .Tokelau:
            return .TK
        case .Tonga:
            return .TO
        case .TrinidadAndTobago:
            return .TT
        case .Tunisia:
            return .TN
        case .Turkey:
            return .TR
        case .Turkmenistan:
            return .TM
        case .TurksAndCaicosIslands:
            return .TC
        case .Tuvalu:
            return .TV
        case .Uganda:
            return .UG
        case .Ukraine:
            return .UA
        case .UnitedArabEmirates:
            return .AE
        case .UnitedKingdomOfGreatBritainAndNorthernIreland:
            return .GB
        case .UnitedStatesMinorOutlyingIslands:
            return .UM
        case .UnitedStatesOfAmerica:
            return .US
        case .Uruguay:
            return .UY
        case .Uzbekistan:
            return .UZ
        case .Vanuatu:
            return .VU
        case .Venezuela:
            return .VE
        case .VietNam:
            return .VN
        case .VirginIslandsBritish:
            return .VG
        case .VirginIslandsUS:
            return .VI
        case .WallisAndFutuna:
            return .WF
        case .WesternSahara:
            return .EH
        case .Yemen:
            return .YE
        case .Zambia:
            return .ZM
        case .Zimbabwe:
            return .ZW
        }
    }
    
    /**
     Will give you the `Alpha3Code` for the specified country.
     
     - parameter country: A `Country` created by the `NVMRegion` Package.
     
     - returns: An `Alpha3Code` matching the given country
     */
    public static func alpha3Code(country: Country) -> Alpha3Code {
        switch country {
        case .Afghanistan:
            return .AFG
        case .AlandIslands:
            return .ALA
        case .Albania:
            return .ALB
        case .Algeria:
            return .DZA
        case .AmericanSamoa:
            return .ASM
        case .Andorra:
            return .AND
        case .Angola:
            return .AGO
        case .Anguilla:
            return .AIA
        case .Antarctica:
            return .ATA
        case .AntiguaAndBarbuda:
            return .ATG
        case .Argentina:
            return .ARG
        case .Armenia:
            return .ARM
        case .Aruba:
            return .ABW
        case .Australia:
            return .AUS
        case .Austria:
            return .AUT
        case .Azerbaijan:
            return .AZE
        case .Bahamas:
            return .BHS
        case .Bahrain:
            return .BHR
        case .Bangladesh:
            return .BGD
        case .Barbados:
            return .BRB
        case .Belarus:
            return .BLR
        case .Belgium:
            return .BEL
        case .Belize:
            return .BLZ
        case .Benin:
            return .BEN
        case .Bermuda:
            return .BMU
        case .Bhutan:
            return .BTN
        case .Bolivia:
            return .BOL
        case .BonaireSintEustatiusAndSaba:
            return .BES
        case .BosniaAndHerzegovina:
            return .BIH
        case .Botswana:
            return .BWA
        case .BouvetIsland:
            return .BVT
        case .Brazil:
            return .BRA
        case .BritishIndianOceanTerritory:
            return .IOT
        case .BruneiDarussalam:
            return .BRN
        case .Bulgaria:
            return .BGR
        case .BurkinaFaso:
            return .BFA
        case .Burundi:
            return .BDI
        case .CapeVerde:
            return .CPV
        case .Cambodia:
            return .KHM
        case .Cameroon:
            return .CMR
        case .Canada:
            return .CAN
        case .CaymanIslands:
            return .CYM
        case .CentralAfricanRepublic:
            return .CAF
        case .Chad:
            return .TCD
        case .Chile:
            return .CHL
        case .China:
            return .CHN
        case .ChristmasIsland:
            return .CXR
        case .CocosIslands:
            return .CCK
        case .Colombia:
            return .COL
        case .Comoros:
            return .COM
        case .TheDemocraticRepublicOfTheCongo:
            return .COD
        case .Congo:
            return .COG
        case .CookIslands:
            return .COK
        case .CostaRica:
            return .CRI
        case .Croatia:
            return .HRV
        case .Cuba:
            return .CUB
        case .Curacao:
            return .CUW
        case .Cyprus:
            return .CYP
        case .Czechia:
            return .CZE
        case .CoteDIvoire:
            return .CIV
        case .Denmark:
            return .DNK
        case .Djibouti:
            return .DJI
        case .Dominica:
            return .DMA
        case .DominicanRepublic:
            return .DOM
        case .Ecuador:
            return .ECU
        case .Egypt:
            return .EGY
        case .ElSalvador:
            return .SLV
        case .EquatorialGuinea:
            return .GNQ
        case .Eritrea:
            return .ERI
        case .Estonia:
            return .EST
        case .Eswatini:
            return .SWZ
        case .Ethiopia:
            return .ETH
        case .FalklandIslands:
            return .FLK
        case .FaroeIslands:
            return .FRO
        case .Fiji:
            return .FJI
        case .Finland:
            return .FIN
        case .France:
            return .FRA
        case .FrenchGuiana:
            return .GUF
        case .FrenchPolynesia:
            return .PYF
        case .FrenchSouthernTerritories:
            return .ATF
        case .Gabon:
            return .GAB
        case .Gambia:
            return .GMB
        case .Georgia:
            return .GEO
        case .Germany:
            return .DEU
        case .Ghana:
            return .GHA
        case .Gibraltar:
            return .GIB
        case .Greece:
            return .GRC
        case .Greenland:
            return .GRL
        case .Grenada:
            return .GRD
        case .Guadeloupe:
            return .GLP
        case .Guam:
            return .GUM
        case .Guatemala:
            return .GTM
        case .Guernsey:
            return .GGY
        case .Guinea:
            return .GIN
        case .GuineaBissau:
            return .GNB
        case .Guyana:
            return .GUY
        case .Haiti:
            return .HTI
        case .HeardIslandAndMcDonaldIslands:
            return .HMD
        case .HolySee:
            return .VAT
        case .Honduras:
            return .HND
        case .HongKong:
            return .HKG
        case .Hungary:
            return .HUN
        case .Iceland:
            return .ISL
        case .India:
            return .IND
        case .Indonesia:
            return .IDN
        case .Iran:
            return .IRN
        case .Iraq:
            return .IRQ
        case .Ireland:
            return .IRL
        case .IsleOfMan:
            return .IMN
        case .Israel:
            return .ISR
        case .Italy:
            return .ITA
        case .Jamaica:
            return .JAM
        case .Japan:
            return .JPN
        case .Jersey:
            return .JEY
        case .Jordan:
            return .JOR
        case .Kazakhstan:
            return .KAZ
        case .Kenya:
            return .KEN
        case .Kiribati:
            return .KIR
        case .TheDemocraticPeoplesRepublicOfKorea:
            return .PRK
        case .Korea:
            return .KOR
        case .Kuwait:
            return .KWT
        case .Kyrgyzstan:
            return .KGZ
        case .Laos:
            return .LAO
        case .Latvia:
            return .LVA
        case .Lebanon:
            return .LBN
        case .Lesotho:
            return .LSO
        case .Liberia:
            return .LBR
        case .Libya:
            return .LBY
        case .Liechtenstein:
            return .LIE
        case .Lithuania:
            return .LTU
        case .Luxembourg:
            return .LUX
        case .Macao:
            return .MAC
        case .Madagascar:
            return .MDG
        case .Malawi:
            return .MWI
        case .Malaysia:
            return .MYS
        case .Maldives:
            return .MDV
        case .Mali:
            return .MLI
        case .Malta:
            return .MLT
        case .MarshallIslands:
            return .MHL
        case .Martinique:
            return .MTQ
        case .Mauritania:
            return .MRT
        case .Mauritius:
            return .MUS
        case .Mayotte:
            return .MYT
        case .Mexico:
            return .MEX
        case .Micronesia:
            return .FSM
        case .Moldova:
            return .MDA
        case .Monaco:
            return .MCO
        case .Mongolia:
            return .MNG
        case .Montenegro:
            return .MNE
        case .Montserrat:
            return .MSR
        case .Morocco:
            return .MAR
        case .Mozambique:
            return .MOZ
        case .Myanmar:
            return .MMR
        case .Namibia:
            return .NAM
        case .Nauru:
            return .NRU
        case .Nepal:
            return .NPL
        case .Netherlands:
            return .NLD
        case .NewCaledonia:
            return .NCL
        case .NewZealand:
            return .NZL
        case .Nicaragua:
            return .NIC
        case .Niger:
            return .NER
        case .Nigeria:
            return .NGA
        case .Niue:
            return .NIU
        case .NorfolkIsland:
            return .NFK
        case .NorthernMarianaIslands:
            return .MNP
        case .Norway:
            return .NOR
        case .Oman:
            return .OMN
        case .Pakistan:
            return .PAK
        case .Palau:
            return .PLW
        case .Palestine:
            return .PSE
        case .Panama:
            return .PAN
        case .PapuaNewGuinea:
            return .PNG
        case .Paraguay:
            return .PRY
        case .Peru:
            return .PER
        case .Philippines:
            return .PHL
        case .Pitcairn:
            return .PCN
        case .Poland:
            return .POL
        case .Portugal:
            return .PRT
        case .PuertoRico:
            return .PRI
        case .Qatar:
            return .QAT
        case .RepublicOfNorthMacedonia:
            return .MKD
        case .Romania:
            return .ROU
        case .RussianFederation:
            return .RUS
        case .Rwanda:
            return .RWA
        case .Reunion:
            return .REU
        case .SaintBarthelemy:
            return .BLM
        case .SaintHelenaAscensionAndTristanDaCunha:
            return .SHN
        case .SaintKittsAndNevis:
            return .KNA
        case .SaintLucia:
            return .LCA
        case .SaintMartin:
            return .MAF
        case .SaintPierreAndMiquelon:
            return .SPM
        case .SaintVincentAndTheGrenadines:
            return .VCT
        case .Samoa:
            return .WSM
        case .SanMarino:
            return .SMR
        case .SaoTomeAndPrincipe:
            return .STP
        case .SaudiArabia:
            return .SAU
        case .Senegal:
            return .SEN
        case .Serbia:
            return .SRB
        case .Seychelles:
            return .SYC
        case .SierraLeone:
            return .SLE
        case .Singapore:
            return .SGP
        case .SintMaarten:
            return .SXM
        case .Slovakia:
            return .SVK
        case .Slovenia:
            return .SVN
        case .SolomonIslands:
            return .SLB
        case .Somalia:
            return .SOM
        case .SouthAfrica:
            return .ZAF
        case .SouthGeorgiaAndTheSouthSandwichIslands:
            return .SGS
        case .SouthSudan:
            return .SSD
        case .Spain:
            return .ESP
        case .SriLanka:
            return .LKA
        case .Sudan:
            return .SDN
        case .Suriname:
            return .SUR
        case .SvalbardAndJanMayen:
            return .SJM
        case .Sweden:
            return .SWE
        case .Switzerland:
            return .CHE
        case .SyrianArabRepublic:
            return .SYR
        case .Taiwan:
            return .TWN
        case .Tajikistan:
            return .TJK
        case .Tanzania:
            return .TZA
        case .Thailand:
            return .THA
        case .TimorLeste:
            return .TLS
        case .Togo:
            return .TGO
        case .Tokelau:
            return .TKL
        case .Tonga:
            return .TON
        case .TrinidadAndTobago:
            return .TTO
        case .Tunisia:
            return .TUN
        case .Turkey:
            return .TUR
        case .Turkmenistan:
            return .TKM
        case .TurksAndCaicosIslands:
            return .TCA
        case .Tuvalu:
            return .TUV
        case .Uganda:
            return .UGA
        case .Ukraine:
            return .UKR
        case .UnitedArabEmirates:
            return .ARE
        case .UnitedKingdomOfGreatBritainAndNorthernIreland:
            return .GBR
        case .UnitedStatesMinorOutlyingIslands:
            return .UMI
        case .UnitedStatesOfAmerica:
            return .USA
        case .Uruguay:
            return .URY
        case .Uzbekistan:
            return .UZB
        case .Vanuatu:
            return .VUT
        case .Venezuela:
            return .VEN
        case .VietNam:
            return .VNM
        case .VirginIslandsBritish:
            return .VGB
        case .VirginIslandsUS:
            return .VIR
        case .WallisAndFutuna:
            return .WLF
        case .WesternSahara:
            return .ESH
        case .Yemen:
            return .YEM
        case .Zambia:
            return .ZMB
        case .Zimbabwe:
            return .ZWE
        }
    }
    
    /**
     Will give you the `Alpha2Code` for the specified country.
     
     - parameter country: A `Country` created by the `NVMRegion` Package.
     
     - returns: An `Alpha2Code` matching the given country
     */
    public static func continent(country: Country) -> Continent {
        switch country {
        case .Afghanistan:
            return .Asia
        case .AlandIslands:
            return .Europe
        case .Albania:
            return .Europe
        case .Algeria:
            return .Africa
        case .AmericanSamoa:
            return .Oceania
        case .Andorra:
            return .Europe
        case .Angola:
            return .Africa
        case .Anguilla:
            return .NorthAmerica
        case .Antarctica:
            return .Antarctica
        case .AntiguaAndBarbuda:
            return .NorthAmerica
        case .Argentina:
            return .SouthAmerica
        case .Armenia:
            return .Asia
        case .Aruba:
            return .NorthAmerica
        case .Australia:
            return .Oceania
        case .Austria:
            return .Europe
        case .Azerbaijan:
            return .Asia
        case .Bahamas:
            return .NorthAmerica
        case .Bahrain:
            return .Asia
        case .Bangladesh:
            return .Asia
        case .Barbados:
            return .NorthAmerica
        case .Belarus:
            return .Europe
        case .Belgium:
            return .Europe
        case .Belize:
            return .NorthAmerica
        case .Benin:
            return .Africa
        case .Bermuda:
            return .NorthAmerica
        case .Bhutan:
            return .Asia
        case .Bolivia:
            return .SouthAmerica
        case .BonaireSintEustatiusAndSaba:
            return .Europe
        case .BosniaAndHerzegovina:
            return .Europe
        case .Botswana:
            return .Africa
        case .BouvetIsland:
            return .Antarctica
        case .Brazil:
            return .SouthAmerica
        case .BritishIndianOceanTerritory:
            return .Africa
        case .BruneiDarussalam:
            return .Asia
        case .Bulgaria:
            return .Europe
        case .BurkinaFaso:
            return .Africa
        case .Burundi:
            return .Africa
        case .CapeVerde:
            return .Africa
        case .Cambodia:
            return .Asia
        case .Cameroon:
            return .Africa
        case .Canada:
            return .NorthAmerica
        case .CaymanIslands:
            return .NorthAmerica
        case .CentralAfricanRepublic:
            return .Africa
        case .Chad:
            return .Africa
        case .Chile:
            return .SouthAmerica
        case .China:
            return .Asia
        case .ChristmasIsland:
            return .Asia
        case .CocosIslands:
            return .Asia
        case .Colombia:
            return .SouthAmerica
        case .Comoros:
            return .Africa
        case .TheDemocraticRepublicOfTheCongo:
            return .Africa
        case .Congo:
            return .Africa
        case .CookIslands:
            return .Oceania
        case .CostaRica:
            return .NorthAmerica
        case .Croatia:
            return .Europe
        case .Cuba:
            return .NorthAmerica
        case .Curacao:
            return .SouthAmerica
        case .Cyprus:
            return .Europe
        case .Czechia:
            return .Europe
        case .CoteDIvoire:
            return .Africa
        case .Denmark:
            return .Europe
        case .Djibouti:
            return .Africa
        case .Dominica:
            return .NorthAmerica
        case .DominicanRepublic:
            return .NorthAmerica
        case .Ecuador:
            return .SouthAmerica
        case .Egypt:
            return .Africa
        case .ElSalvador:
            return .NorthAmerica
        case .EquatorialGuinea:
            return .Africa
        case .Eritrea:
            return .Africa
        case .Estonia:
            return .Europe
        case .Eswatini:
            return .Africa
        case .Ethiopia:
            return .Africa
        case .FalklandIslands:
            return .SouthAmerica
        case .FaroeIslands:
            return .Europe
        case .Fiji:
            return .Oceania
        case .Finland:
            return .Europe
        case .France:
            return .Europe
        case .FrenchGuiana:
            return .SouthAmerica
        case .FrenchPolynesia:
            return .Oceania
        case .FrenchSouthernTerritories:
            return .Antarctica
        case .Gabon:
            return .Africa
        case .Gambia:
            return .Africa
        case .Georgia:
            return .Asia
        case .Germany:
            return .Europe
        case .Ghana:
            return .Africa
        case .Gibraltar:
            return .Europe
        case .Greece:
            return .Europe
        case .Greenland:
            return .NorthAmerica
        case .Grenada:
            return .NorthAmerica
        case .Guadeloupe:
            return .NorthAmerica
        case .Guam:
            return .Oceania
        case .Guatemala:
            return .NorthAmerica
        case .Guernsey:
            return .Europe
        case .Guinea:
            return .Africa
        case .GuineaBissau:
            return .Africa
        case .Guyana:
            return .SouthAmerica
        case .Haiti:
            return .NorthAmerica
        case .HeardIslandAndMcDonaldIslands:
            return .Antarctica
        case .HolySee:
            return .Europe
        case .Honduras:
            return .NorthAmerica
        case .HongKong:
            return .Asia
        case .Hungary:
            return .Europe
        case .Iceland:
            return .Europe
        case .India:
            return .Asia
        case .Indonesia:
            return .Asia
        case .Iran:
            return .Asia
        case .Iraq:
            return .Asia
        case .Ireland:
            return .Europe
        case .IsleOfMan:
            return .Europe
        case .Israel:
            return .Asia
        case .Italy:
            return .Europe
        case .Jamaica:
            return .NorthAmerica
        case .Japan:
            return .Asia
        case .Jersey:
            return .Europe
        case .Jordan:
            return .Asia
        case .Kazakhstan:
            return .Asia
        case .Kenya:
            return .Africa
        case .Kiribati:
            return .Oceania
        case .TheDemocraticPeoplesRepublicOfKorea:
            return .Asia
        case .Korea:
            return .Asia
        case .Kuwait:
            return .Asia
        case .Kyrgyzstan:
            return .Asia
        case .Laos:
            return .Asia
        case .Latvia:
            return .Europe
        case .Lebanon:
            return .Asia
        case .Lesotho:
            return .Africa
        case .Liberia:
            return .Africa
        case .Libya:
            return .Africa
        case .Liechtenstein:
            return .Europe
        case .Lithuania:
            return .Europe
        case .Luxembourg:
            return .Europe
        case .Macao:
            return .Asia
        case .Madagascar:
            return .Africa
        case .Malawi:
            return .Africa
        case .Malaysia:
            return .Asia
        case .Maldives:
            return .Asia
        case .Mali:
            return .Africa
        case .Malta:
            return .Europe
        case .MarshallIslands:
            return .Oceania
        case .Martinique:
            return .NorthAmerica
        case .Mauritania:
            return .Africa
        case .Mauritius:
            return .Africa
        case .Mayotte:
            return .Africa
        case .Mexico:
            return .NorthAmerica
        case .Micronesia:
            return .Oceania
        case .Moldova:
            return .Europe
        case .Monaco:
            return .Europe
        case .Mongolia:
            return .Asia
        case .Montenegro:
            return .Europe
        case .Montserrat:
            return .NorthAmerica
        case .Morocco:
            return .Africa
        case .Mozambique:
            return .Africa
        case .Myanmar:
            return .Asia
        case .Namibia:
            return .Africa
        case .Nauru:
            return .Oceania
        case .Nepal:
            return .Asia
        case .Netherlands:
            return .Europe
        case .NewCaledonia:
            return .Oceania
        case .NewZealand:
            return .Oceania
        case .Nicaragua:
            return .NorthAmerica
        case .Niger:
            return .Africa
        case .Nigeria:
            return .Africa
        case .Niue:
            return .Oceania
        case .NorfolkIsland:
            return .Oceania
        case .NorthernMarianaIslands:
            return .Oceania
        case .Norway:
            return .Europe
        case .Oman:
            return .Asia
        case .Pakistan:
            return .Asia
        case .Palau:
            return .Oceania
        case .Palestine:
            return .Asia
        case .Panama:
            return .NorthAmerica
        case .PapuaNewGuinea:
            return .Oceania
        case .Paraguay:
            return .SouthAmerica
        case .Peru:
            return .SouthAmerica
        case .Philippines:
            return .Asia
        case .Pitcairn:
            return .Oceania
        case .Poland:
            return .Europe
        case .Portugal:
            return .Europe
        case .PuertoRico:
            return .NorthAmerica
        case .Qatar:
            return .Asia
        case .RepublicOfNorthMacedonia:
            return .Europe
        case .Romania:
            return .Europe
        case .RussianFederation:
            return .Europe
        case .Rwanda:
            return .Africa
        case .Reunion:
            return .Africa
        case .SaintBarthelemy:
            return .NorthAmerica
        case .SaintHelenaAscensionAndTristanDaCunha:
            return .Africa
        case .SaintKittsAndNevis:
            return .NorthAmerica
        case .SaintLucia:
            return .NorthAmerica
        case .SaintMartin:
            return .NorthAmerica
        case .SaintPierreAndMiquelon:
            return .NorthAmerica
        case .SaintVincentAndTheGrenadines:
            return .NorthAmerica
        case .Samoa:
            return .Oceania
        case .SanMarino:
            return .Europe
        case .SaoTomeAndPrincipe:
            return .Africa
        case .SaudiArabia:
            return .Asia
        case .Senegal:
            return .Africa
        case .Serbia:
            return .Europe
        case .Seychelles:
            return .Africa
        case .SierraLeone:
            return .Africa
        case .Singapore:
            return .Asia
        case .SintMaarten:
            return .NorthAmerica
        case .Slovakia:
            return .Europe
        case .Slovenia:
            return .Europe
        case .SolomonIslands:
            return .Oceania
        case .Somalia:
            return .Africa
        case .SouthAfrica:
            return .Africa
        case .SouthGeorgiaAndTheSouthSandwichIslands:
            return .Antarctica
        case .SouthSudan:
            return .Africa
        case .Spain:
            return .Europe
        case .SriLanka:
            return .Asia
        case .Sudan:
            return .Africa
        case .Suriname:
            return .SouthAmerica
        case .SvalbardAndJanMayen:
            return .Europe
        case .Sweden:
            return .Europe
        case .Switzerland:
            return .Europe
        case .SyrianArabRepublic:
            return .Asia
        case .Taiwan:
            return .Asia
        case .Tajikistan:
            return .Asia
        case .Tanzania:
            return .Africa
        case .Thailand:
            return .Asia
        case .TimorLeste:
            return .Asia
        case .Togo:
            return .Africa
        case .Tokelau:
            return .Oceania
        case .Tonga:
            return .Oceania
        case .TrinidadAndTobago:
            return .NorthAmerica
        case .Tunisia:
            return .Africa
        case .Turkey:
            return .Asia
        case .Turkmenistan:
            return .Asia
        case .TurksAndCaicosIslands:
            return .NorthAmerica
        case .Tuvalu:
            return .Oceania
        case .Uganda:
            return .Africa
        case .Ukraine:
            return .Europe
        case .UnitedArabEmirates:
            return .Asia
        case .UnitedKingdomOfGreatBritainAndNorthernIreland:
            return .Europe
        case .UnitedStatesMinorOutlyingIslands:
            return .NorthAmerica
        case .UnitedStatesOfAmerica:
            return .NorthAmerica
        case .Uruguay:
            return .SouthAmerica
        case .Uzbekistan:
            return .Asia
        case .Vanuatu:
            return .Oceania
        case .Venezuela:
            return .SouthAmerica
        case .VietNam:
            return .Asia
        case .VirginIslandsBritish:
            return .NorthAmerica
        case .VirginIslandsUS:
            return .NorthAmerica
        case .WallisAndFutuna:
            return .Oceania
        case .WesternSahara:
            return .Africa
        case .Yemen:
            return .Asia
        case .Zambia:
            return .Africa
        case .Zimbabwe:
            return .Africa
        }
    }
    
    /**
     Will give you the `Numeric` for the specified country.
     
     - parameter country: A `Country` created by the `NVMRegion` Package.
     
     - returns: A `Numeric` matching the given country
     */
    public static func numeric(country: Country) -> Numeric {
        switch country {
        case .Afghanistan:
            return .N004
        case .AlandIslands:
            return .N248
        case .Albania:
            return .N008
        case .Algeria:
            return .N012
        case .AmericanSamoa:
            return .N016
        case .Andorra:
            return .N020
        case .Angola:
            return .N024
        case .Anguilla:
            return .N660
        case .Antarctica:
            return .N010
        case .AntiguaAndBarbuda:
            return .N028
        case .Argentina:
            return .N032
        case .Armenia:
            return .N051
        case .Aruba:
            return .N533
        case .Australia:
            return .N036
        case .Austria:
            return .N040
        case .Azerbaijan:
            return .N031
        case .Bahamas:
            return .N044
        case .Bahrain:
            return .N048
        case .Bangladesh:
            return .N050
        case .Barbados:
            return .N052
        case .Belarus:
            return .N112
        case .Belgium:
            return .N056
        case .Belize:
            return .N084
        case .Benin:
            return .N204
        case .Bermuda:
            return .N060
        case .Bhutan:
            return .N064
        case .Bolivia:
            return .N068
        case .BonaireSintEustatiusAndSaba:
            return .N535
        case .BosniaAndHerzegovina:
            return .N070
        case .Botswana:
            return .N072
        case .BouvetIsland:
            return .N074
        case .Brazil:
            return .N076
        case .BritishIndianOceanTerritory:
            return .N086
        case .BruneiDarussalam:
            return .N096
        case .Bulgaria:
            return .N100
        case .BurkinaFaso:
            return .N854
        case .Burundi:
            return .N108
        case .CapeVerde:
            return .N132
        case .Cambodia:
            return .N116
        case .Cameroon:
            return .N120
        case .Canada:
            return .N124
        case .CaymanIslands:
            return .N136
        case .CentralAfricanRepublic:
            return .N140
        case .Chad:
            return .N148
        case .Chile:
            return .N152
        case .China:
            return .N156
        case .ChristmasIsland:
            return .N162
        case .CocosIslands:
            return .N166
        case .Colombia:
            return .N170
        case .Comoros:
            return .N174
        case .TheDemocraticRepublicOfTheCongo:
            return .N180
        case .Congo:
            return .N178
        case .CookIslands:
            return .N184
        case .CostaRica:
            return .N188
        case .Croatia:
            return .N191
        case .Cuba:
            return .N192
        case .Curacao:
            return .N531
        case .Cyprus:
            return .N196
        case .Czechia:
            return .N203
        case .CoteDIvoire:
            return .N384
        case .Denmark:
            return .N208
        case .Djibouti:
            return .N262
        case .Dominica:
            return .N212
        case .DominicanRepublic:
            return .N214
        case .Ecuador:
            return .N218
        case .Egypt:
            return .N818
        case .ElSalvador:
            return .N222
        case .EquatorialGuinea:
            return .N226
        case .Eritrea:
            return .N232
        case .Estonia:
            return .N233
        case .Eswatini:
            return .N748
        case .Ethiopia:
            return .N231
        case .FalklandIslands:
            return .N238
        case .FaroeIslands:
            return .N234
        case .Fiji:
            return .N242
        case .Finland:
            return .N246
        case .France:
            return .N250
        case .FrenchGuiana:
            return .N254
        case .FrenchPolynesia:
            return .N258
        case .FrenchSouthernTerritories:
            return .N260
        case .Gabon:
            return .N266
        case .Gambia:
            return .N270
        case .Georgia:
            return .N268
        case .Germany:
            return .N276
        case .Ghana:
            return .N288
        case .Gibraltar:
            return .N292
        case .Greece:
            return .N300
        case .Greenland:
            return .N304
        case .Grenada:
            return .N308
        case .Guadeloupe:
            return .N312
        case .Guam:
            return .N316
        case .Guatemala:
            return .N320
        case .Guernsey:
            return .N831
        case .Guinea:
            return .N324
        case .GuineaBissau:
            return .N624
        case .Guyana:
            return .N328
        case .Haiti:
            return .N332
        case .HeardIslandAndMcDonaldIslands:
            return .N334
        case .HolySee:
            return .N336
        case .Honduras:
            return .N340
        case .HongKong:
            return .N344
        case .Hungary:
            return .N348
        case .Iceland:
            return .N352
        case .India:
            return .N356
        case .Indonesia:
            return .N360
        case .Iran:
            return .N364
        case .Iraq:
            return .N368
        case .Ireland:
            return .N372
        case .IsleOfMan:
            return .N833
        case .Israel:
            return .N376
        case .Italy:
            return .N380
        case .Jamaica:
            return .N388
        case .Japan:
            return .N392
        case .Jersey:
            return .N832
        case .Jordan:
            return .N400
        case .Kazakhstan:
            return .N398
        case .Kenya:
            return .N404
        case .Kiribati:
            return .N296
        case .TheDemocraticPeoplesRepublicOfKorea:
            return .N408
        case .Korea:
            return .N410
        case .Kuwait:
            return .N414
        case .Kyrgyzstan:
            return .N417
        case .Laos:
            return .N418
        case .Latvia:
            return .N428
        case .Lebanon:
            return .N422
        case .Lesotho:
            return .N426
        case .Liberia:
            return .N430
        case .Libya:
            return .N434
        case .Liechtenstein:
            return .N438
        case .Lithuania:
            return .N440
        case .Luxembourg:
            return .N442
        case .Macao:
            return .N446
        case .Madagascar:
            return .N450
        case .Malawi:
            return .N454
        case .Malaysia:
            return .N458
        case .Maldives:
            return .N462
        case .Mali:
            return .N466
        case .Malta:
            return .N470
        case .MarshallIslands:
            return .N584
        case .Martinique:
            return .N474
        case .Mauritania:
            return .N478
        case .Mauritius:
            return .N480
        case .Mayotte:
            return .N175
        case .Mexico:
            return .N484
        case .Micronesia:
            return .N583
        case .Moldova:
            return .N498
        case .Monaco:
            return .N492
        case .Mongolia:
            return .N496
        case .Montenegro:
            return .N499
        case .Montserrat:
            return .N500
        case .Morocco:
            return .N504
        case .Mozambique:
            return .N508
        case .Myanmar:
            return .N104
        case .Namibia:
            return .N516
        case .Nauru:
            return .N520
        case .Nepal:
            return .N524
        case .Netherlands:
            return .N528
        case .NewCaledonia:
            return .N540
        case .NewZealand:
            return .N554
        case .Nicaragua:
            return .N558
        case .Niger:
            return .N562
        case .Nigeria:
            return .N566
        case .Niue:
            return .N570
        case .NorfolkIsland:
            return .N574
        case .NorthernMarianaIslands:
            return .N580
        case .Norway:
            return .N578
        case .Oman:
            return .N512
        case .Pakistan:
            return .N586
        case .Palau:
            return .N585
        case .Palestine:
            return .N275
        case .Panama:
            return .N591
        case .PapuaNewGuinea:
            return .N598
        case .Paraguay:
            return .N600
        case .Peru:
            return .N604
        case .Philippines:
            return .N608
        case .Pitcairn:
            return .N612
        case .Poland:
            return .N616
        case .Portugal:
            return .N620
        case .PuertoRico:
            return .N630
        case .Qatar:
            return .N634
        case .RepublicOfNorthMacedonia:
            return .N807
        case .Romania:
            return .N642
        case .RussianFederation:
            return .N643
        case .Rwanda:
            return .N646
        case .Reunion:
            return .N638
        case .SaintBarthelemy:
            return .N652
        case .SaintHelenaAscensionAndTristanDaCunha:
            return .N654
        case .SaintKittsAndNevis:
            return .N659
        case .SaintLucia:
            return .N662
        case .SaintMartin:
            return .N663
        case .SaintPierreAndMiquelon:
            return .N666
        case .SaintVincentAndTheGrenadines:
            return .N670
        case .Samoa:
            return .N882
        case .SanMarino:
            return .N674
        case .SaoTomeAndPrincipe:
            return .N678
        case .SaudiArabia:
            return .N682
        case .Senegal:
            return .N686
        case .Serbia:
            return .N688
        case .Seychelles:
            return .N690
        case .SierraLeone:
            return .N694
        case .Singapore:
            return .N702
        case .SintMaarten:
            return .N534
        case .Slovakia:
            return .N703
        case .Slovenia:
            return .N705
        case .SolomonIslands:
            return .N090
        case .Somalia:
            return .N706
        case .SouthAfrica:
            return .N710
        case .SouthGeorgiaAndTheSouthSandwichIslands:
            return .N239
        case .SouthSudan:
            return .N728
        case .Spain:
            return .N724
        case .SriLanka:
            return .N144
        case .Sudan:
            return .N729
        case .Suriname:
            return .N740
        case .SvalbardAndJanMayen:
            return .N744
        case .Sweden:
            return .N752
        case .Switzerland:
            return .N756
        case .SyrianArabRepublic:
            return .N760
        case .Taiwan:
            return .N158
        case .Tajikistan:
            return .N762
        case .Tanzania:
            return .N834
        case .Thailand:
            return .N764
        case .TimorLeste:
            return .N626
        case .Togo:
            return .N768
        case .Tokelau:
            return .N772
        case .Tonga:
            return .N776
        case .TrinidadAndTobago:
            return .N780
        case .Tunisia:
            return .N788
        case .Turkey:
            return .N792
        case .Turkmenistan:
            return .N795
        case .TurksAndCaicosIslands:
            return .N796
        case .Tuvalu:
            return .N798
        case .Uganda:
            return .N800
        case .Ukraine:
            return .N804
        case .UnitedArabEmirates:
            return .N784
        case .UnitedKingdomOfGreatBritainAndNorthernIreland:
            return .N826
        case .UnitedStatesMinorOutlyingIslands:
            return .N581
        case .UnitedStatesOfAmerica:
            return .N840
        case .Uruguay:
            return .N858
        case .Uzbekistan:
            return .N860
        case .Vanuatu:
            return .N548
        case .Venezuela:
            return .N862
        case .VietNam:
            return .N704
        case .VirginIslandsBritish:
            return .N092
        case .VirginIslandsUS:
            return .N850
        case .WallisAndFutuna:
            return .N876
        case .WesternSahara:
            return .N732
        case .Yemen:
            return .N887
        case .Zambia:
            return .N894
        case .Zimbabwe:
            return .N716
        }
    }
    
    /**
     Will give you the `LanguageCode` for the specified language.
     
     - parameter language: A `Language` created by the `NVMRegion` Package.
     
     - returns: A `LanguageCode` matching the given language
     */
    public static func languageCode(language: Language) -> LanguageCode {
        switch language {
        case .Arabic:
            return .ar
        case .Catalan:
            return .ca
        case .ChineseHK:
            return .zhHK
        case .ChineseHans:
            return .zhHans
        case .ChineseHant:
            return .zhHant
        case .Croatian:
            return .hr
        case .Czech:
            return .cs
        case .Danish:
            return .da
        case .Dutch:
            return .nl
        case .English:
            return .en
        case .EnglishAU:
            return .enAU
        case .EnglishIN:
            return .enIN
        case .EnglishGB:
            return .enGB
        case .Finnish:
            return .fi
        case .French:
            return .fr
        case .FrenchCA:
            return .frCA
        case .German:
            return .de
        case .Greek:
            return .el
        case .Hebrew:
            return .he
        case .Hindi:
            return .hi
        case .Hungarian:
            return .hu
        case .Indonesian:
            return .id
        case .Italian:
            return .it
        case .Japanese:
            return .ja
        case .Korean:
            return .ko
        case .Malay:
            return .ms
        case .NorwegianBokmal:
            return .nb
        case .Polish:
            return .pl
        case .PortugueseBR:
            return .ptBR
        case .PortuguesePT:
            return .ptPT
        case .Romanian:
            return .ro
        case .Russian:
            return .ru
        case .Slovak:
            return .sk
        case .Spanish:
            return .es
        case .Spanish419:
            return .es419
        case .Swedish:
            return .sv
        case .Thai:
            return .th
        case .Turkish:
            return .tr
        case .Ukrainian:
            return .uk
        case .Vietnamese:
            return .vi
        }
    }
}
